#! /usr/bin/perl -w

# File       : example_signprediction.pl
# Authors    : Vinayagam Arunachalam
# Date 	     : April 8th 2013

# Copyright (c) 2013 Vinayagam Arunachalam; Harvard Medical School

# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:

# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT.  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.


#
# This is an example program to predict signed PPI for Drosophila
# This program uses published Drosophila RNAi screens (42 screens) as phenotype matrix and 
# predicts signs for selected PPIs (example PPIs)
# 
# To apply this program to other species
#  1. Construct phenotype matrix for the corresponding species (please see the POD or Drosophila phenotype matrix file for file format)
#  2. Compile PPIs for the corresponding species
#  3. Use SignPredictor with phenotype matrix as input and predict signs for the PPIs
#
# Note: The gene IDs of Phenotype matrix should match the gene IDs of PPI network
# 


use SignPredictor;

#
# Creating SignPredictor object using phenotype matrix as input
# with default parameters
#
# Change the Phenotype matrix file to predict signs for other species
#
# 

my $SignPredictor = SignPredictor->new(	PhenotypeMatrixFile 	=> "Drosophila_PhenotypeMatrix.tsv",
					ZScoreCutoff       	=> 1.5,
					RNAiScreenCutoff	=> 2,
					SignScoreCutoff		=> 1);


#
# print the signed network as standard output
#

print "Gene1\tGene2\tEdge_sign\tSign_score\tNumber_of_Screens\n";

#
# Reads the example PPI file
#
# Change the PPI file to predict signs for other species
#

open (INP1, "<Drosophila_PPINetwork.tsv");
<INP1>;
while(<INP1>) {
	chomp;
	my ($gene1, $gene2) = split(/\t/);
	my $sign = $SignPredictor->Predict_PPISign($gene1, $gene2);
    	if (defined($sign)) {
		print "$gene1\t$gene2\t$sign->{PPI_sign}\t$sign->{sign_score}\t$sign->{phenotypes}\n";
	}
}
close(INP1);


=pod

=head1 DESCRIPTION


 This is an example program to predict signed PPI for Drosophila
 This program uses published Drosophila RNAi screens (42 screens) as phenotype matrix and 
 predicts signs for selected PPIs (example PPIs)
 
 To apply this program to other species
  1. Construct phenotype matrix for the corresponding species (please see the POD or Drosophila phenotype matrix for file format)
  2. Compile PPIs for the corresponding species
  3. Use SignPredictor with phenotype matrix as input and predict signs for the PPIs

 Note: The gene IDs of Phenotype matrix should match the gene IDs of PPI network
 

=cut

